--- layout: template title: API - pyatv.exceptions permalink: /api//exceptions link_group: api ---

# Module `pyatv.exceptions`

Local exceptions used by library.

Expand source code

    """Local exceptions used by library."""

    class NoServiceError(Exception):
        """Thrown when connecting to a device with no usable service."""

    class UnsupportedProtocolError(Exception):
        """Thrown when an unsupported protocol was requested.

        DEPRECATED: Not used since 0.8.0. Will be removed in 0.10.0!
        """

    class ConnectionFailedError(Exception):
        """Thrown when connection fails, e.g. refused or timed out."""

    class PairingError(Exception):
        """Thrown when pairing fails."""

    class AuthenticationError(Exception):
        """Thrown when authentication fails."""

    class NotSupportedError(NotImplementedError):
        """Thrown when trying to perform an action that is not supported."""

    class InvalidDmapDataError(Exception):
        """Thrown when invalid DMAP data is parsed."""

    class UnknownMediaKindError(Exception):
        """Thrown when an unknown media kind is found."""

    class UnknownPlayStateError(Exception):
        """Thrown when an unknown play state is found."""

    class NoAsyncListenerError(Exception):
        """Thrown when starting AsyncUpdater with no listener."""

    class NoCredentialsError(Exception):
        """Thrown if credentials are missing."""

    class InvalidCredentialsError(Exception):
        """Thrown if credentials are invalid."""

    class DeviceIdMissingError(Exception):
        """Thrown when device id is missing."""

    class BackOffError(Exception):
        """Thrown when device mandates a backoff period."""

    class PlaybackError(Exception):
        """Thrown when media playback failed."""

    class CommandError(Exception):
        """Thrown when a command (e.g. play or pause) failed."""

    class NonLocalSubnetError(Exception):
        """Thrown when address it not in any local subnet.

        DEPRECATED: Not used since 0.7.1. Will be removed in 0.9.0!
        """

    class InvalidStateError(Exception):
        """Thrown when trying to perform an action not possible in the current state."""

    class ProtocolError(Exception):
        """Thrown when a generic protocol error occurs.

        Generic protocol errors includes for instance missing fields, incorrect or
        unexpected types, etc. Any error that can happen when communicating with a device
        that is not covered by another exception is covered by this exception.
        """

    class InvalidConfigError(Exception):
        """Thrown when something is wrong or missing in the config."""

## Classes

`class AuthenticationError (*args, **kwargs)`

  Thrown when authentication fails.

  Expand source code

      class AuthenticationError(Exception):
          """Thrown when authentication fails."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class BackOffError (*args, **kwargs)`

  Thrown when device mandates a backoff period.

  Expand source code

      class BackOffError(Exception):
          """Thrown when device mandates a backoff period."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class CommandError (*args, **kwargs)`

  Thrown when a command (e.g. play or pause) failed.

  Expand source code

      class CommandError(Exception):
          """Thrown when a command (e.g. play or pause) failed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ConnectionFailedError (*args, **kwargs)`

  Thrown when connection fails, e.g. refused or timed out.

  Expand source code

      class ConnectionFailedError(Exception):
          """Thrown when connection fails, e.g. refused or timed out."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class DeviceIdMissingError (*args, **kwargs)`

  Thrown when device id is missing.

  Expand source code

      class DeviceIdMissingError(Exception):
          """Thrown when device id is missing."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidConfigError (*args, **kwargs)`

  Thrown when something is wrong or missing in the config.

  Expand source code

      class InvalidConfigError(Exception):
          """Thrown when something is wrong or missing in the config."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidCredentialsError (*args, **kwargs)`

  Thrown if credentials are invalid.

  Expand source code

      class InvalidCredentialsError(Exception):
          """Thrown if credentials are invalid."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidDmapDataError (*args, **kwargs)`

  Thrown when invalid DMAP data is parsed.

  Expand source code

      class InvalidDmapDataError(Exception):
          """Thrown when invalid DMAP data is parsed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidStateError (*args, **kwargs)`

  Thrown when trying to perform an action not possible in the current state.

  Expand source code

      class InvalidStateError(Exception):
          """Thrown when trying to perform an action not possible in the current state."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoAsyncListenerError (*args, **kwargs)`

  Thrown when starting AsyncUpdater with no listener.

  Expand source code

      class NoAsyncListenerError(Exception):
          """Thrown when starting AsyncUpdater with no listener."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoCredentialsError (*args, **kwargs)`

  Thrown if credentials are missing.

  Expand source code

      class NoCredentialsError(Exception):
          """Thrown if credentials are missing."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NoServiceError (*args, **kwargs)`

  Thrown when connecting to a device with no usable service.

  Expand source code

      class NoServiceError(Exception):
          """Thrown when connecting to a device with no usable service."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NonLocalSubnetError (*args, **kwargs)`

  Thrown when address it not in any local subnet.

  DEPRECATED: Not used since 0.7.1. Will be removed in 0.9.0!

  Expand source code

      class NonLocalSubnetError(Exception):
          """Thrown when address it not in any local subnet.

          DEPRECATED: Not used since 0.7.1. Will be removed in 0.9.0!
          """

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class NotSupportedError (*args, **kwargs)`

  Thrown when trying to perform an action that is not supported.

  Expand source code

      class NotSupportedError(NotImplementedError):
          """Thrown when trying to perform an action that is not supported."""

  ### Ancestors

  - builtins.NotImplementedError
  - builtins.RuntimeError
  - builtins.Exception
  - builtins.BaseException
`class PairingError (*args, **kwargs)`

  Thrown when pairing fails.

  Expand source code

      class PairingError(Exception):
          """Thrown when pairing fails."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class PlaybackError (*args, **kwargs)`

  Thrown when media playback failed.

  Expand source code

      class PlaybackError(Exception):
          """Thrown when media playback failed."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ProtocolError (*args, **kwargs)`

  Thrown when a generic protocol error occurs.

  Generic protocol errors includes for instance missing fields, incorrect or unexpected types, etc. Any error that can happen when communicating with a device that is not covered by another exception is covered by this exception.

  Expand source code

      class ProtocolError(Exception):
          """Thrown when a generic protocol error occurs.

          Generic protocol errors includes for instance missing fields, incorrect or
          unexpected types, etc. Any error that can happen when communicating with a device
          that is not covered by another exception is covered by this exception.
          """

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnknownMediaKindError (*args, **kwargs)`

  Thrown when an unknown media kind is found.

  Expand source code

      class UnknownMediaKindError(Exception):
          """Thrown when an unknown media kind is found."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnknownPlayStateError (*args, **kwargs)`

  Thrown when an unknown play state is found.

  Expand source code

      class UnknownPlayStateError(Exception):
          """Thrown when an unknown play state is found."""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class UnsupportedProtocolError (*args, **kwargs)`

  Thrown when an unsupported protocol was requested.

  DEPRECATED: Not used since 0.8.0. Will be removed in 0.10.0!

  Expand source code

      class UnsupportedProtocolError(Exception):
          """Thrown when an unsupported protocol was requested.

          DEPRECATED: Not used since 0.8.0. Will be removed in 0.10.0!
          """

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException